@@ -83,6 +83,8 @@ def check_access_rights(service: str,
                         firebase_auth.InvalidIdTokenError) as e:
                     if required_rights != 'None':
                         return {'detail': 'You don\'t have access to Adscale resources\n', 'firebase_log': str(e)}, 401
+                except ValueError as e:
+                    return {'detail': str(e)}, 401
 
                 try:
                     send_tracking_information(claims['email'], service, job_func.__name__, project,
