@@ -5,7 +5,7 @@ from typing import Callable
 from flask import request
 
 from .authentication import get_user_email
-from arcane.pubsub import pubsub_message_decoder
+from arcane.pubsub.utils import pubsub_json_message_decoder
 
 
 def catch_exceptions_service(service: str, pubsub_subscriber: bool=False) -> Callable:
@@ -20,7 +20,7 @@ def catch_exceptions_service(service: str, pubsub_subscriber: bool=False) -> Cal
                     job_func_signature = inspect.signature(job_func)
                     message_kw = list(job_func_signature.parameters.keys())[0]
                     message_data = kwargs[message_kw]['message']['data']
-                    decoded_pay_load = pubsub_message_decoder(message_data)
+                    decoded_pay_load = pubsub_json_message_decoder(message_data)
                     parameters = decoded_pay_load['parameters']
                 except (KeyError, ValueError, IndexError, TypeError):
                     parameters = kwargs
